%define lib_major	1
%define lib_name	%mklibname jq %{lib_major}
%define develname	%mklibname jq -d

Name:		jq
Version:	1.7.1
Release:	%mkrel 3
Summary:	Command-line JSON processor
Group:		System/Base
License:	MIT and ASL 2.0 and CC-BY and GPLv3
URL:		https://stedolan.github.io/jq/
Source0:	https://github.com/stedolan/jq/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
Patch0:		jq-1.7.1-mga-disable-rpath.patch

BuildRequires:	flex
BuildRequires:	bison
BuildRequires:	pkgconfig(oniguruma)


%description
lightweight and flexible command-line JSON processor

 jq is like sed for JSON data – you can use it to slice
 and filter and map and transform structured data with
 the same ease that sed, awk, grep and friends let you
 play with text.

 It is written in portable C, and it has zero runtime
 dependencies.

 jq can mangle the data format that you have into the
 one that you want with very little effort, and the
 program to do so is often shorter and simpler than
 you'd expect.

%package -n %{lib_name}
Summary:	Libraries for %{name}
Group:		System/Libraries

%description -n %{lib_name}
This package contains libraries used by %{name}.



%package -n %{develname}
Summary:	Development files for %{name}
Requires:	%{name} = %{version}-%{release}
Requires:	%{lib_name} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files for %{name}.


%prep
%autosetup -p1

# fix version info, needed if we run autoreconf (mga#33050)
sed -i -e "s/test -d.*/echo %{version} \&\& exit/" scripts/version

%build
# std=gnu17 fixes ftbfs with gcc15
# upstream fix for gcc 15 should be in > 1.7.1
export CFLAGS="%{optflags} -std=gnu17"
autoreconf -vfi
%configure --disable-static --disable-valgrind
%make_build
# Docs already shipped in jq's tarball.
# In order to build the manual page, it
# is necessary to install rake, rubygem-ronn
# and do the following steps:
#
# # yum install rake rubygem-ronn
# $ cd docs/
# $ curl -L https://get.rvm.io | bash -s stable --ruby=1.9.3
# $ source $HOME/.rvm/scripts/rvm
# $ bundle install
# $ cd ..
# $ ./configure
# $ make real_docs

%install
%make_install

find %{buildroot} -name '*.la' -delete

%check
%__make check

%files
%{_bindir}/%{name}
%{_mandir}/man1/jq.1.*
%{_datadir}/doc/jq/AUTHORS
%{_datadir}/doc/jq/COPYING
%{_datadir}/doc/jq/NEWS.md
%{_datadir}/doc/jq/README.md
%dir %{_datadir}/doc/jq

%files -n %{lib_name}
%{_libdir}/libjq.so.%{lib_major}{,.*}

%files -n %{develname}
%{_includedir}/jq.h
%{_includedir}/jv.h
%{_libdir}/libjq.so
%{_libdir}/pkgconfig/libjq.pc


%changelog
* Fri May 16 2025 ns80 <ns80> 1.7.1-3.mga10
+ Revision: 2183772
- try to fix building with GCC 15

* Wed Apr 03 2024 daviddavid <daviddavid> 1.7.1-2.mga10
+ Revision: 2054035
- fix version info not returned properly when we use autoreconf (mga#33050)

* Fri Jan 26 2024 ns80 <ns80> 1.7.1-1.mga10
+ Revision: 2035054
- new version 1.7.1 for CVE-2023-50246 and CVE-2023-50268 (mga#32640)

* Mon Nov 27 2023 daviddavid <daviddavid> 1.7-1.mga10
+ Revision: 2010128
- new version: 1.7

* Wed Mar 23 2022 umeabot <umeabot> 1.6-3.mga9
+ Revision: 1821291
- Mageia 9 Mass Rebuild

* Sat Mar 19 2022 danf <danf> 1.6-2.mga9
+ Revision: 1800731
- Stop setting an rpath during build to drop a useless rpath in the final binary.

* Fri Feb 14 2020 umeabot <umeabot> 1.6-2.mga8
+ Revision: 1520236
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Nov 10 2018 daviddavid <daviddavid> 1.6-1.mga7
+ Revision: 1329263
- new version: 1.6
- remove merged upstream patches

* Sun Sep 23 2018 umeabot <umeabot> 1.5-5.mga7
+ Revision: 1298392
- Mageia 7 Mass Rebuild

* Wed Mar 21 2018 daviddavid <daviddavid> 1.5-4.mga7
+ Revision: 1210883
- rebuild for new oniguruma 6.8.1

* Fri Nov 10 2017 luigiwalser <luigiwalser> 1.5-3.mga7
+ Revision: 1176842
- add patches from opensuse to fix CVE-2015-8863 and CVE-2016-4074

* Sun Oct 15 2017 daviddavid <daviddavid> 1.5-2.mga7
+ Revision: 1172026
- add some missing provides from devel subpakage
- fix dependencies from devel subpackge

* Sat Mar 25 2017 ovitters <ovitters> 1.5-1.mga6
+ Revision: 1094799
- add group
- from fedora


* Sun Oct 30 2016 Mamoru TASAKA <mtasaka@fedoraproject.org> - 1.5-5
- Rebuild for oniguruma 6.1.1

* Mon Jul 18 2016 Mamoru TASAKA <mtasaka@fedoraproject.org> - 1.5-4
- Rebuild for oniguruma 6

* Sun Mar 13 2016 Peter Robinson <pbrobinson@fedoraproject.org> 1.5-3
- valgrind on all but s390

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Aug 25 2015 Haïkel Guémar <hguemar@fedoraproject.org> - 1.5-1
- Upstream 1.5.0

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Oct 24 2013 Flavio Percoco <flavio@redhat.com> - 1.3-2
- Added check, manpage

* Fri Oct 18 2013 Flavio Percoco <flavio@redhat.com> - 1.3-1
- Initial package release.
